==> react-7.11.0.tgz: package/es/Icon/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

/**
 * @category styles
 * @component icon
 * @variations collab-ui-react
 */
import React from 'react';
import PropTypes from 'prop-types';
import { find, chain, startCase, trimEnd, trimStart } from 'lodash';
import iconPaths from '@collab-ui/icons/data/iconsData.json';
import colors from '@collab-ui/core/data/colors.json';
import { Button } from "./..";
var count = 0;

var Icon = function Icon(props) {
  var name = props.name,
      size = props.size,
      className = props.className,
      color = props.color,
      isClickable = props.isClickable,
      title = props.title,
      description = props.description,
      isAria = props.isAria,
      type = props.type,
      otherHTMLProps = _objectWithoutProperties(props, ["name", "size", "className", "color", "isClickable", "title", "description", "isAria", "type"]);

  var iconCount = count++;
  var titleId = "icon-title-" + iconCount;
  var descId = description ? "icon-desc-" + iconCount : undefined;

  var consoleHandler = function consoleHandler(message, data) {
    /* eslint-disable no-console */
    switch (message) {
      case 'color-warn':
        console.warn(data + " may not exist in the design system," + " please use a color name from http://collab-ui.cisco.com/styles/colors");
        break;

      case 'color-error':
        console.warn(data + " does not exist in the design system," + " please use a color name from http://collab-ui.cisco.com/styles/colors");
        break;

      case 'name-error':
        console.warn("Icon " + data + " does not exist in the design system." + " Visit http://collab-ui-icons.cisco.com for a list of available icons or to request a new icon.");
        break;
    }
    /* eslint-enable no-console */

  };

  var getSize = function getSize() {
    var defaultSize = 16;
    var sizeFromName = Number(name.split('_')[1]);
    return size || sizeFromName || defaultSize;
  };

  var getColorSpec = function getColorSpec(colorObj) {
    return colorObj.hex ? colorObj.hex : colorObj.opacity && isolateRoot(colorObj.variable) === 'white' ? "rgba(255, 255, 255, " + colorObj.opacity / 100 + ")" : "rgba(0, 0, 0, " + colorObj.opacity / 100 + ")";
  };

  var getHexFromJSON = function getHexFromJSON(colorName) {
    for (var _iterator = colors, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
      var _ref;

      if (_isArray) {
        if (_i >= _iterator.length) break;
        _ref = _iterator[_i++];
      } else {
        _i = _iterator.next();
        if (_i.done) break;
        _ref = _i.value;
      }

      var c = _ref;
      var variation = find(c.variations, ['variable', colorName]);
      if (variation) return getColorSpec(variation);
    }

    return consoleHandler('color-error', colorName);
  };

  var isolateRoot = function isolateRoot(str) {
    return chain(str).trimStart('$').split('-').value()[0];
  };

  var formatColor = function formatColor() {
    return color.startsWith('$') ? color : color.endsWith('-base') ? trimEnd(color, '-base') : "$" + color;
  };

  var getColor = function getColor() {
    if (!color) return 'inherit';

    if (color.startsWith('#')) {
      consoleHandler('color-warn', color);
      return color;
    }

    return getHexFromJSON(formatColor());
  };

  var getPaths = function getPaths() {
    var iconName = name.startsWith('icon-') ? trimStart(name, 'icon-') : name;
    return iconPaths[iconName] ? iconPaths[iconName].map(function (icoPath, index) {
      return React.createElement("path", {
        d: icoPath,
        key: index
      });
    }) : consoleHandler('name-error', iconName);
  };

  var getAria = function getAria() {
    return description ? titleId + " " + descId : "" + titleId;
  };

  var getTitle = function getTitle() {
    return !title ? startCase(name) : title;
  };

  return isClickable ? React.createElement(Button, _extends({
    className: 'cui-button--icon' + ("" + (type && " cui-button--icon-" + type || ''))
  }, otherHTMLProps), React.createElement("svg", {
    className: "cui-icon" + ("" + (className && " " + className || '')),
    width: getSize(),
    height: getSize(),
    "aria-labelledby": isAria ? getAria() : undefined
  }, isAria && React.createElement("title", {
    id: titleId
  }, getTitle()), description && isAria && React.createElement("desc", {
    id: descId
  }, description), React.createElement("g", {
    fill: getColor(),
    fillRule: "evenodd"
  }, getPaths()))) : React.createElement("svg", _extends({
    className: "cui-icon" + ("" + (className && " " + className || '')),
    width: getSize(),
    height: getSize(),
    "aria-labelledby": isAria ? getAria() : undefined
  }, otherHTMLProps), isAria && React.createElement("title", {
    id: titleId
  }, getTitle()), description && isAria && React.createElement("desc", {
    id: descId
  }, description), React.createElement("g", {
    fill: getColor(),
    fillRule: "evenodd"
  }, getPaths()));
};

Icon.propTypes = {
  isClickable: PropTypes.bool,
  name: PropTypes.string.isRequired,
  size: PropTypes.number,
  color: PropTypes.string,
  className: PropTypes.string,
  isAria: PropTypes.bool,
  title: PropTypes.string,
  description: PropTypes.string,
  type: PropTypes.oneOf(['', 'white'])
};
Icon.defaultProps = {
  color: '',
  className: '',
  isClickable: false,
  isAria: true,
  type: ''
};
Icon.displayName = 'Icon';
export default Icon;
/**
*
* @category communication
* @component icon
* @section default
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <Icon name='accessories_16' />
        <Icon name='accessories_20' />
        <Icon name='accessories_36' />
        <Icon name='accessories_56' />
      </div>
    );
  }
}
**/

/**
*
* @category communication
* @component icon
* @section color
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <Icon name='accessories_16' color='blue' />
        <Icon name='accessories_20' color='blue' />
        <Icon name='accessories_36' color='blue' />
        <Icon name='accessories_56' color='blue' />
      </div>
    );
  }
}
**/

/**
*
* @category communication
* @component icon
* @section click
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <Icon name='accessories_16' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 16 - clicked')} />
        <Icon name='accessories_20' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 20 - clicked')} />
        <Icon name='accessories_36' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 36 - clicked')} />
        <Icon name='accessories_56' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 56 - clicked')} />
      </div>
    );
  }
}
**/

/**
*
* @category communication
* @component icon
* @section type
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <div className='row'>
          <div>Default</div>
          <div style={{padding: '5px'}}>
            <Icon name='clear-active_24' ariaLabel='Clear' isClickable onClick={() => console.log('Icon 20 - clicked')} />
          </div>
        </div>
        <div className='row'>
          <div>Type(white)</div>
          <div style={{ backgroundColor: 'black', padding: '5px', width: 'fit-content'}}>
            <Icon name='clear-active_24' ariaLabel='Clear' type='white' isClickable onClick={() => console.log('Icon 36 - clicked')} />
          </div>
        </div>
      </div>
    );
  }
}
**/

==> react-7.13.1.tgz: package/es/Icon/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

/**
 * @category styles
 * @component icon
 * @variations collab-ui-react
 */
import React from 'react';
import PropTypes from 'prop-types';
import { find, chain, startCase, trimEnd, trimStart, uniqueId } from 'lodash';
import iconPaths from '@collab-ui/icons/data/iconsData.json';
import colors from '@collab-ui/core/data/colors.json';
import { Button } from "./..";

var Icon = function Icon(props) {
  var name = props.name,
      size = props.size,
      className = props.className,
      color = props.color,
      isClickable = props.isClickable,
      title = props.title,
      description = props.description,
      isAria = props.isAria,
      type = props.type,
      otherHTMLProps = _objectWithoutProperties(props, ["name", "size", "className", "color", "isClickable", "title", "description", "isAria", "type"]);

  var iconCount = uniqueId();
  var titleId = "icon-title-" + iconCount;
  var descId = description ? "icon-desc-" + iconCount : undefined;

  var consoleHandler = function consoleHandler(message, data) {
    /* eslint-disable no-console */
    switch (message) {
      case 'color-warn':
        console.warn(data + " may not exist in the design system," + " please use a color name from http://collab-ui.cisco.com/styles/colors");
        break;

      case 'color-error':
        console.warn(data + " does not exist in the design system," + " please use a color name from http://collab-ui.cisco.com/styles/colors");
        break;

      case 'name-error':
        console.warn("Icon " + data + " does not exist in the design system." + " Visit http://collab-ui-icons.cisco.com for a list of available icons or to request a new icon.");
        break;
    }
    /* eslint-enable no-console */

  };

  var getSize = function getSize() {
    var defaultSize = 16;
    var sizeFromName = Number(name.split('_')[1]);
    return size || sizeFromName || defaultSize;
  };

  var getColorSpec = function getColorSpec(colorObj) {
    return colorObj.hex ? colorObj.hex : colorObj.opacity && isolateRoot(colorObj.variable) === 'white' ? "rgba(255, 255, 255, " + colorObj.opacity / 100 + ")" : "rgba(0, 0, 0, " + colorObj.opacity / 100 + ")";
  };

  var getHexFromJSON = function getHexFromJSON(colorName) {
    for (var _iterator = colors, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
      var _ref;

      if (_isArray) {
        if (_i >= _iterator.length) break;
        _ref = _iterator[_i++];
      } else {
        _i = _iterator.next();
        if (_i.done) break;
        _ref = _i.value;
      }

      var c = _ref;
      var variation = find(c.variations, ['variable', colorName]);
      if (variation) return getColorSpec(variation);
    }

    return consoleHandler('color-error', colorName);
  };

  var isolateRoot = function isolateRoot(str) {
    return chain(str).trimStart('$').split('-').value()[0];
  };

  var formatColor = function formatColor() {
    return color.startsWith('$') ? color : color.endsWith('-base') ? trimEnd(color, '-base') : "$" + color;
  };

  var getColor = function getColor() {
    if (!color) return 'inherit';

    if (color.startsWith('#')) {
      consoleHandler('color-warn', color);
      return color;
    }

    return getHexFromJSON(formatColor());
  };

  var getPaths = function getPaths() {
    var iconName = name.startsWith('icon-') ? trimStart(name, 'icon-') : name;
    return iconPaths[iconName] ? iconPaths[iconName].map(function (icoPath, index) {
      return React.createElement("path", {
        d: icoPath,
        key: index
      });
    }) : consoleHandler('name-error', iconName);
  };

  var getAria = function getAria() {
    return description ? titleId + " " + descId : "" + titleId;
  };

  var getTitle = function getTitle() {
    return !title ? startCase(name) : title;
  };

  return isClickable ? React.createElement(Button, _extends({
    className: 'cui-button--icon' + ("" + (type && " cui-button--icon-" + type || ''))
  }, otherHTMLProps), React.createElement("svg", {
    className: "cui-icon" + ("" + (className && " " + className || '')),
    width: getSize(),
    height: getSize(),
    "aria-labelledby": isAria ? getAria() : undefined
  }, isAria && React.createElement("title", {
    id: titleId
  }, getTitle()), description && isAria && React.createElement("desc", {
    id: descId
  }, description), React.createElement("g", {
    fill: getColor(),
    fillRule: "evenodd"
  }, getPaths()))) : React.createElement("svg", _extends({
    className: "cui-icon" + ("" + (className && " " + className || '')),
    width: getSize(),
    height: getSize(),
    "aria-labelledby": isAria ? getAria() : undefined
  }, otherHTMLProps), isAria && React.createElement("title", {
    id: titleId
  }, getTitle()), description && isAria && React.createElement("desc", {
    id: descId
  }, description), React.createElement("g", {
    fill: getColor(),
    fillRule: "evenodd"
  }, getPaths()));
};

Icon.propTypes = {
  isClickable: PropTypes.bool,
  name: PropTypes.string.isRequired,
  size: PropTypes.number,
  color: PropTypes.string,
  className: PropTypes.string,
  isAria: PropTypes.bool,
  title: PropTypes.string,
  description: PropTypes.string,
  type: PropTypes.oneOf(['', 'white'])
};
Icon.defaultProps = {
  color: '',
  className: '',
  isClickable: false,
  isAria: true,
  type: ''
};
Icon.displayName = 'Icon';
export default Icon;
/**
*
* @category communication
* @component icon
* @section default
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <Icon name='accessories_16' />
        <Icon name='accessories_20' />
        <Icon name='accessories_36' />
        <Icon name='accessories_56' />
      </div>
    );
  }
}
**/

/**
*
* @category communication
* @component icon
* @section color
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <Icon name='accessories_16' color='blue' />
        <Icon name='accessories_20' color='blue' />
        <Icon name='accessories_36' color='blue' />
        <Icon name='accessories_56' color='blue' />
      </div>
    );
  }
}
**/

/**
*
* @category communication
* @component icon
* @section click
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <Icon name='accessories_16' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 16 - clicked')} />
        <Icon name='accessories_20' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 20 - clicked')} />
        <Icon name='accessories_36' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 36 - clicked')} />
        <Icon name='accessories_56' color='blue' ariaLabel='Accessories' isClickable onClick={() => console.log('Icon 56 - clicked')} />
      </div>
    );
  }
}
**/

/**
*
* @category communication
* @component icon
* @section type
*
* @js
*

export default class Default extends React.PureComponent {

  render() {
    return(
      <div>
        <div className='row'>
          <div>Default</div>
          <div style={{padding: '5px'}}>
            <Icon name='clear-active_24' ariaLabel='Clear' isClickable onClick={() => console.log('Icon 20 - clicked')} />
          </div>
        </div>
        <div className='row'>
          <div>Type(white)</div>
          <div style={{ backgroundColor: 'black', padding: '5px', width: 'fit-content'}}>
            <Icon name='clear-active_24' ariaLabel='Clear' type='white' isClickable onClick={() => console.log('Icon 36 - clicked')} />
          </div>
        </div>
      </div>
    );
  }
}
**/
